%define url_ver %(echo %{version}|cut -d. -f1,2)

%define soversion %{url_ver}
%define libname   %mklibname %name %soversion
%define devname   %mklibname %name -d

Summary:        The SWORD Project framework for manipulating Bible texts
Name:           sword
Version:        1.9.0
Release:        %mkrel 11
License:        GPLv2+
Group:          System/Libraries
URL:            https://www.crosswire.org/sword/software/
Source:         https://www.crosswire.org/ftpmirror/pub/sword/source/v%{url_ver}/%{name}-%{version}.tar.gz
Source2:        sword_icons.tar.bz2
Patch0:         cmake-perl-bindings.diff
# Patch1 emailed to upstream
Patch1:         migrate-to-setuptools.diff
BuildRequires:  cmake
BuildRequires:  icu
BuildRequires:  swig
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(icu-i18n)
BuildRequires:  pkgconfig(libidn)
BuildRequires:  pkgconfig(libclucene-core)
BuildRequires:  pkgconfig(cppunit)
BuildRequires:  pkgconfig(python3)
BuildRequires:  python3dist(setuptools)

Requires:       curl


%description
The SWORD Project is an effort to create an ever expanding software package
for research and study of God and His Word.  The SWORD Framework
allows easy manipulation of Bible texts, commentaries, lexicons, dictionaries,
etc.  Many frontends are build using this framework.  An installed module
set may be shared between any frontend using the framework.

%package -n %{libname}
Summary:         Main library for SWORD
Group:           System/Libraries

%description -n %{libname}
This package contains the library needed to run programs dynamically
linked with SWORD.

%package -n %{devname}
Summary:         Development files for SWORD
Group:           Development/C
Requires:        %{libname} = %{version}-%{release}
Provides:        %{name}-devel = %{version}-%{release}
Provides:        lib%{name}-devel = %{version}-%{release}

%description -n %{devname}
This package contains the headers that programmers
will need to develop applications which will use the SWORD Bible Framework.

%package -n python3-sword
Summary:         Python3 bindings for Sword
Group:           Development/Python
%{?python_provide:%python_provide python3-sword}
Requires:        python3

%description -n python3-sword
Python 3 bindings for The SWORD Library.

%prep
%setup -q -a2
%autopatch -p1

%build
%cmake -DLIBSWORD_LIBRARY_TYPE=Shared \
       -DSWORD_PYTHON_3:BOOL=TRUE \
       -DSWORD_PERL:BOOL=FALSE \
       -DSWORD_BUILD_UTILS="Yes" \
       -DLIBSWORD_SOVERSION=%{soversion} \
       -DLIBDIR=%{_libdir} \
       -DSWORD_BUILD_TESTS=Yes \
       -DSWORD_PYTHON_INSTALL_ROOT="%{buildroot}" \
       -DSWORD_PYTHON_INSTALL_DIR="%{_prefix}"
%cmake_build

%install
%cmake_install

rm -f doc/Makefile.am samples/Makefile.am

%files
%doc README AUTHORS NEWS ChangeLog
%doc samples/ doc/*.*
%license COPYING LICENSE
%{_bindir}/*
%{_datadir}/%{name}/
%config(noreplace) %{_sysconfdir}/sword.conf

%files -n %{libname}
%license COPYING LICENSE
%{_libdir}/*%{name}.so.%{soversion}

%files -n %{devname}
%{_includedir}/sword/
%{_libdir}/*%{name}.so
%{_libdir}/pkgconfig/*.pc

%files -n python3-sword
%{python3_sitearch}/Sword.py
%{python3_sitearch}/_Sword%{python3_ext_suffix}
%{python3_sitearch}/__pycache__/*
%{python3_sitearch}/sword-%{version}-py%{python3_version}.egg-info/


%changelog
* Thu Dec 28 2023 daviddavid <daviddavid> 1.9.0-11.mga10
+ Revision: 2023295
- add fedora patch to migrate to setuptools
- use distutils from setuptools
- rebuild for py3.12

* Tue Oct 10 2023 daviddavid <daviddavid> 1.9.0-10.mga10
+ Revision: 1994136
- rebuild for icu73

* Sat Jan 07 2023 squidf <squidf> 1.9.0-9.mga9
+ Revision: 1931172
- Mass rebuild for icu 72.1

* Mon Aug 08 2022 mrambo3501 <mrambo3501> 1.9.0-8.mga9
+ Revision: 1876116
- use Python's bundled distutils

* Sun Aug 07 2022 mrambo3501 <mrambo3501> 1.9.0-7.mga9
+ Revision: 1876009
- fix filelists

* Sat Jun 18 2022 squidf <squidf> 1.9.0-6.mga9
+ Revision: 1864906
- rebuild for icu 71.1

* Fri Apr 01 2022 umeabot <umeabot> 1.9.0-5.mga9
+ Revision: 1839341
- Mageia 9 Mass Rebuild

* Mon Feb 14 2022 tmb <tmb> 1.9.0-4.mga9
+ Revision: 1774925
- rebuild for python 3.10

* Tue Aug 03 2021 luigiwalser <luigiwalser> 1.9.0-3.mga9
+ Revision: 1738975
- rebuild for icu

* Sat Mar 20 2021 daviddavid <daviddavid> 1.9.0-2.mga9
+ Revision: 1705396
- rebuild for python 3.9

* Wed Mar 03 2021 daviddavid <daviddavid> 1.9.0-1.mga9
+ Revision: 1697193
- new version: 1.9.0
- use now a real libmajor 1.9
- switch to cmake build system
- enable the python3 binding

* Mon Nov 30 2020 luigiwalser <luigiwalser> 1.8.1-9.mga8
+ Revision: 1650931
- rebuild for icu

* Wed Jul 01 2020 wally <wally> 1.8.1-8.mga8
+ Revision: 1601069
- rebuild for icu 67.1
+ pterjan <pterjan>
- Remove usage of obsolete macros (https://github.com/rpm-software-management/rpm/issues/1211)

* Sun Apr 26 2020 daviddavid <daviddavid> 1.8.1-7.mga8
+ Revision: 1572237
- add patch to fix upstream markup bug

* Sat Apr 04 2020 wally <wally> 1.8.1-6.mga8
+ Revision: 1564504
- rebuild for new icu 66.1

* Sun Feb 16 2020 umeabot <umeabot> 1.8.1-5.mga8
+ Revision: 1534619
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sat Oct 05 2019 daviddavid <daviddavid> 1.8.1-4.mga8
+ Revision: 1449460
- rebuild for new icu 65.1

* Sat Dec 29 2018 luigiwalser <luigiwalser> 1.8.1-3.mga7
+ Revision: 1346118
- rebuild for icu

* Mon Aug 27 2018 daviddavid <daviddavid> 1.8.1-2.mga7
+ Revision: 1255068
- rebuild for new icu

* Sat Jan 20 2018 daviddavid <daviddavid> 1.8.1-1.mga7
+ Revision: 1195040
- new version: 1.8.1

* Fri Dec 29 2017 wally <wally> 1.7.5-2.mga7
+ Revision: 1187015
- rebuild for new icu

* Sun Oct 15 2017 daviddavid <daviddavid> 1.7.5-1.mga7
+ Revision: 1172043
- new version: 1.7.5a1
- patch0: fix build with gcc7

* Wed Mar 15 2017 mrambo3501 <mrambo3501> 1.7.3-8.mga6
+ Revision: 1092809
- Rebuild for icu-58.2

* Sat May 14 2016 shlomif <shlomif> 1.7.3-7.mga6
+ Revision: 1015249
- Rebuild for the new UCI (new major)

* Fri Jan 01 2016 luigiwalser <luigiwalser> 1.7.3-6.mga6
+ Revision: 917924
- rebuild for icu

* Thu Sep 03 2015 cjw <cjw> 1.7.3-5.mga6
+ Revision: 872420
- rebuild with gcc 5

* Fri Jul 24 2015 cjw <cjw> 1.7.3-4.mga6
+ Revision: 856814
- rebuild for icu 55

* Wed Oct 15 2014 umeabot <umeabot> 1.7.3-3.mga5
+ Revision: 740151
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.7.3-2.mga5
+ Revision: 689646
- Mageia 5 Mass Rebuild

* Tue Sep 09 2014 akien <akien> 1.7.3-1.mga5
+ Revision: 674152
- Version 1.7.3

* Sat Apr 05 2014 wally <wally> 1.6.2-15.mga5
+ Revision: 611900
- rebuild for new icu

* Mon Oct 21 2013 umeabot <umeabot> 1.6.2-14.mga4
+ Revision: 537322
- Mageia 4 Mass Rebuild

* Thu Sep 26 2013 fwang <fwang> 1.6.2-13.mga4
+ Revision: 486814
- rebuild for icu 52

* Sun May 26 2013 fwang <fwang> 1.6.2-12.mga4
+ Revision: 428042
- rebuild for icu

* Mon Jan 14 2013 umeabot <umeabot> 1.6.2-11.mga3
+ Revision: 383858
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Nov 06 2012 fwang <fwang> 1.6.2-10.mga3
+ Revision: 314741
- fix build with latest gcc
- rebuild for new icu

* Tue May 29 2012 ovitters <ovitters> 1.6.2-9.mga3
+ Revision: 249444
- rebuild due to new libicu

* Fri Sep 30 2011 fwang <fwang> 1.6.2-8.mga2
+ Revision: 150476
- rebuild for new clucene

* Wed Sep 28 2011 doktor5000 <doktor5000> 1.6.2-6.mga2
+ Revision: 149881
- fix missing curl/types.h compile problem (no-curl-types.patch, from Fedora)
- remove .la and .a files
- remove -static subpackage
- remove Makefile.am from installed files
- proper libification, removed unused major
- fixed Summary and Group of -devel subpackage
- fixed Summary for libsword subpackage
- added BuildRequires on clucene-devel, idn-devel, zlib-devel, openssl-devel and cppunit
- added configure switches to explicitly enable zlib-, icu- and clucene-support
- removed obsolete %%defattrs, %%clean and BuildRoot
- removed versioned Build-/Requires for curl
- removed Obsoletes
- imported package sword


* Mon Jun 20 2011 Oden Eriksson <oeriksson@mandriva.com> 1.6.2-4mdv2011.0
+ Revision: 686324
- avoid pulling 32 bit libraries on 64 bit arch

* Sun Jun 05 2011 Funda Wang <fwang@mandriva.org> 1.6.2-3
+ Revision: 682818
- rebuild for new icu

* Mon Mar 14 2011 Funda Wang <fwang@mandriva.org> 1.6.2-2
+ Revision: 644601
- cleanup old language section
- rebuild for new icu

* Mon Oct 25 2010 Buchan Milne <bgmilne@mandriva.org> 1.6.2-1mdv2011.0
+ Revision: 589290
- New version 1.6.2
- fix the icu transliteration file paths to not embed version numbers

* Mon Sep 06 2010 Buchan Milne <bgmilne@mandriva.org> 1.6.1-1mdv2011.0
+ Revision: 576291
- Buildrequires icu and icu-devel
- New version 1.6.1

* Sat Jun 06 2009 Frederik Himpe <fhimpe@mandriva.org> 1.6.0-1mdv2010.0
+ Revision: 383327
- Update to new version 1.6.0

* Fri Aug 15 2008 Buchan Milne <bgmilne@mandriva.org> 1.5.11-1mdv2009.0
+ Revision: 272232
- update to new version 1.5.11

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild
    - rebuild
    - kill re-definition of %%buildroot on Pixel's request

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Fri Dec 07 2007 Funda Wang <fwang@mandriva.org> 1.5.10-1mdv2008.1
+ Revision: 116226
- New version 1.5.10


* Sat Jan 06 2007 David Walluck <walluck@mandriva.org> 1.5.9-1mdv2007.0
+ Revision: 104737
- 1.5.9

* Sat Jan 06 2007 David Walluck <walluck@mandriva.org> 1.5.8-3mdv2007.1
+ Revision: 104726
- Import sword

* Thu Sep 07 2006 Buchan Milne <bgmilne@mandriva.org> 1.5.8-3mdv2007.0
- rebuild

* Fri Nov 25 2005 Buchan Milne <bgmilne@mandriva.org> 1.5.8-2mdk
- rebuild to provide missing srpm

* Wed Sep 14 2005 Buchan Milne <bgmilne@linux-mandrake.com> 1.5.8-1mdk
- New release 1.5.8
- make it build on x86_64 (use %%configure)
- cleanups
- use %%mkrel (since it can do everything the excess macros were doing)
- rpmbuildupdate-able
- drop p0

* Thu Aug 26 2004 Buchan Milne<bgmilne@linux-mandrake.com> 1.5.7a-1mdk
- bump lib major
- changes from Lonnie Borntreger <cooker@borntreger.com>
  - rework patch0 for new source snapshot
  - remove patch1, merged upstream

* Wed Jul 28 2004 Thierry Vignaud <tvignaud@mandrakesoft.com> 1.5.7-4mdk
- lowerize optimization level thus preventing some segfaults in libsword3

* Wed Jul 28 2004 Thierry Vignaud <tvignaud@mandrakesoft.com> 1.5.7-3mdk
- rebuild

* Sat Jul 17 2004 Buchan Milne <bgmilne@linux-mandrake.com> 1.5.7-3mdk
- rebuild for curl, fix requires/buildrequires

* Wed Jun 16 2004 Laurent MONTEL <lmontel@mandrakesoft.com> 1.5.7-2mdk
- Rebuild

